@@ -7,13 +7,19 @@ bdgraph.ts = function( data, Nlength = NULL, n, iter = 1000, burnin = iter / 2,
 					   g.start = "empty", g.space = NULL, prior.df = rep( 3, Nlength ), 
 					   save.all = FALSE, cores = "all" )
 {
+	check.os( os = 2 )	
+	
 	if( cores == "all" ) cores = detect_cores()
+	
+	tmp   <- .C( "check_nthread", cores = as.integer(cores), PACKAGE = "BDgraph" )
+	cores <- tmp $ cores
+	
 	.C( "omp_set_num_cores", as.integer( cores ), PACKAGE = "BDgraph" )
 	
 	burnin    = floor( burnin )
 
-	if( !is.matrix(data) & !is.data.frame(data) ) stop( "Data should be a matrix or dataframe" )
-	if( is.data.frame(data) ) data <- data.matrix(data)
+	if( !is.matrix( data ) & !is.data.frame(data) ) stop( "Data should be a matrix or dataframe" )
+	if( is.data.frame( data ) ) data <- data.matrix(data)
 	if( iter <= burnin )   stop( "Number of iteration must be more than number of burn-in" )
 
 	if( any( is.na( data ) ) ) stop( "This method does not deal with missing value" )
