@@ -27,13 +27,20 @@ rgcwish = function( n = 1, adj.g = NULL, b = 3, D = NULL )
 	row2    = cbind( Im(inv_D), Re(inv_D) )
 	sig     = rbind( row1, row2 ) / 2
 	Ls      = t( chol(sig) )
-	samples = array( 0, c( p, p, n ) )
 	K       = matrix( 0, p, p )
 	
-	for( i in 1 : n )
+	
+	if( n > 1 )
 	{
-		result       = .C( "rgcwish_c", as.integer(G), as.double(Ls), K = as.complex(K), as.integer(b), as.integer(p), PACKAGE = "BDgraph" )
-		samples[,,i] = matrix( result $ K, p, p ) 		
+		samples = array( 0, c( p, p, n ) )
+		for( i in 1 : n )
+		{
+			result       = .C( "rgcwish_c", as.integer(G), as.double(Ls), K = as.complex(K), as.integer(b), as.integer(p), PACKAGE = "BDgraph" )
+			samples[,,i] = matrix( result $ K, p, p ) 		
+		}
+	}else{
+		result  = .C( "rgcwish_c", as.integer(G), as.double(Ls), K = as.complex(K), as.integer(b), as.integer(p), PACKAGE = "BDgraph" )
+		samples = matrix( result $ K, p, p ) 				
 	}	
 
 	return( samples )   
